# fixtures/deployments

A collection of example deployments that can be used for testing.

## Policies & Procedures

- all files must end in `.yml`
- file names must be descriptive
- changes must not alter existing index locations
- respect any comments in individual files pertaining to changes
